fisx: Member List

fisx

fisx::Elements Member List

This is the complete list of members for fisx::Elements, including all inherited members.

addElement(const Element &elementInstance) | fisx::Elements |
addMaterial(const Material &materialInstance, const int &errorOnReplace=1) | fisx::Elements |
addMaterial(const std::string &name, const double &density=1.0, const double &thickness=1.0, const std::string &comment="", const int &errorOnReplace=1) | fisx::Elements |
clearCache(const std::string &elementName) | fisx::Elements |
clearEscapeCache(void) | fisx::Elements |
createMaterial(const std::string &name, const double &density=1.0, const double &thickness=1.0, const std::string &comment="") | fisx::Elements |
defaultDataDir() | fisx::Elements | static
Elements(std::string dataDirectory="") | fisx::Elements |
Elements(std::string dataDirectory, short pymca) | fisx::Elements |
Elements(std::string dataDirectory, std::string bindingEnergiesFile, std::string crossSectionsFile="") | fisx::Elements |
emptyElementCascadeCache(const std::string &elementName) (defined in fisx::Elements) | fisx::Elements |
fillCache(const std::string &elementName, const std::vector< double > &energy) | fisx::Elements |
fillElementCascadeCache(const std::string &elementName) (defined in fisx::Elements) | fisx::Elements |
getAtomicMass(const std::string &name) const | fisx::Elements |
getAtomicNumber(const std::string &name) const | fisx::Elements |
getBindingEnergies(const std::string &name) const | fisx::Elements |
getCacheSize(const std::string &elementName) const | fisx::Elements |
getCascadeModifiedVacancyDistribution(const std::string &elementName, const std::map< std::string, double > &distribution) const (defined in fisx::Elements) | fisx::Elements |
getColumn(const std::string &name) const | fisx::Elements |
getComposition(const std::string &name) const | fisx::Elements |
getComposition(const std::string &name, const std::vector< Material > &materials) const | fisx::Elements |
getCompositionFromFormula(const std::string &formula) const | fisx::Elements |
getDensity(const std::string &name) const | fisx::Elements |
getElement(const std::string &elementName) const | fisx::Elements |
getElementCopy(const std::string &elementName) | fisx::Elements |
getElementNames() | fisx::Elements |
getEmittedXRayLines(const std::string &elementName, const double &energy=1000.) const | fisx::Elements |
getEscape(const std::map< std::string, double > &composition, const double &energy, const double &energyThreshold=0.010, const double &intensityThreshold=1.0e-7, const int &nThreshold=4, const double &alphaIn=90., const double &thickness=0.0) const | fisx::Elements |
getExcitationFactors(const std::string &element, const std::vector< double > &energy, const std::vector< double > &weights=std::vector< double >()) const | fisx::Elements |
getExcitationFactors(const std::string &element, const double &energy, const double &weights=1.0) const | fisx::Elements |
getInitialPhotoelectricVacancyDistribution(const std::string &elementName, const std::vector< double > &energies) const | fisx::Elements |
getInitialPhotoelectricVacancyDistribution(const std::string &elementName, const double &energy) const | fisx::Elements |
getLongName(const std::string &name) const | fisx::Elements |
getMassAttenuationCoefficients(const std::string &elementName) const | fisx::Elements |
getMassAttenuationCoefficients(const std::string &formula, const std::vector< double > &energies) const | fisx::Elements |
getMassAttenuationCoefficients(std::map< std::string, double > elementMassFractions, std::vector< double > energies) const | fisx::Elements |
getMassAttenuationCoefficients(std::string formula, double energy) const | fisx::Elements |
getMassAttenuationCoefficients(std::map< std::string, double > elementMassFractions, double energies) const | fisx::Elements |
getMaterial(const std::string &materialName) | fisx::Elements |
getMaterialCopy(const std::string &materialName) | fisx::Elements |
getMaterialNames() | fisx::Elements |
getNonradiativeTransitions(const std::string &elementName, const std::string &subshell) const | fisx::Elements |
getPeakFamilies(const std::string &name, const double &energy) const | fisx::Elements |
getPeakFamilies(const std::vector< std::string > &elementList, const double &energy) const | fisx::Elements |
getRadiativeTransitions(const std::string &elementName, const std::string &subshell) const | fisx::Elements |
getRow(const std::string &name) const | fisx::Elements |
getShellConstants(const std::string &elementName, const std::string &subshell) const | fisx::Elements |
getShellConstantsFile(const std::string &mainShellName) const | fisx::Elements |
getShellNonradiativeTransitionsFile(const std::string &mainShellName) const | fisx::Elements |
getShellRadiativeTransitionsFile(const std::string &mainShellName) const | fisx::Elements |
getXRayLinesFromVacancyDistribution(const std::string &elementName, const std::map< std::string, double > &distribution, const int &cascade=1, const int &useFluorescenceYield=1) const | fisx::Elements |
isCacheEnabled(const std::string &elementName) const | fisx::Elements |
isElementCascadeCacheFilled(const std::string &elementName) const (defined in fisx::Elements) | fisx::Elements |
isElementNameDefined(const std::string &elementName) const | fisx::Elements |
isEscapeCacheEnabled() const (defined in fisx::Elements) | fisx::Elements | inline
parseFormula(const std::string &formula) const | fisx::Elements |
removeMaterial(const std::string &name) | fisx::Elements |
removeMaterials() | fisx::Elements |
setCacheEnabled(const std::string &elementName, const int &flag=1) | fisx::Elements |
setElementCascadeCacheEnabled(const std::string &elementName, const int &flag=1) | fisx::Elements |
setEscapeCacheEnabled(const int &flag=1) (defined in fisx::Elements) | fisx::Elements | inline
setMassAttenuationCoefficients(const std::string &elementName, const std::vector< double > &energy, const std::vector< double > &photoelectric, const std::vector< double > &coherent, const std::vector< double > &compton, const std::vector< double > &pair) | fisx::Elements |
setMassAttenuationCoefficientsFile(const std::string &fileName) | fisx::Elements |
setMaterialComposition(const std::string &materialName, const std::map< std::string, double > &composition) | fisx::Elements |
setMaterialComposition(const std::string &materialName, const std::vector< std::string > &names, const std::vector< double > &amounts) | fisx::Elements |
setShellConstantsFile(const std::string &mainShellName, const std::string &fileName) | fisx::Elements |
setShellNonradiativeTransitionsFile(const std::string &mainShellName, const std::string &fileName) | fisx::Elements |
setShellRadiativeTransitionsFile(const std::string &mainShellName, const std::string &fileName) | fisx::Elements |
stringToDouble(const std::string &str, double &number) | fisx::Elements | static
toString(const double &number) | fisx::Elements | static
updateCache(const std::string &elementName, const std::vector< double > &energy) | fisx::Elements |
updateEscapeCache(const std::map< std::string, double > &composition, const std::vector< double > &energy, const double &energyThreshold=0.010, const double &intensityThreshold=1.0e-7, const int &nThreshold=4, const double &alphaIn=90., const double &thickness=0.0) | fisx::Elements |